package com.caimei365.user.controller;

import com.caimei365.user.model.ResponseJson;
import com.caimei365.user.model.dto.ClubTemporaryDto;
import com.caimei365.user.model.dto.OnlineDto;
import com.caimei365.user.model.po.ServiceProviderPo;
import com.caimei365.user.model.vo.ClubTemporaryVo;
import com.caimei365.user.model.vo.ClubVo;
import com.caimei365.user.service.SellerService;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.apache.commons.lang.StringUtils;
import org.springframework.web.bind.annotation.*;

import java.util.Map;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/3/24
 */
@Api(tags = "协销用户API")
@RestController
@RequiredArgsConstructor
@RequestMapping("/user/seller")
public class SellerApi {

    private final SellerService sellerService;

    /**
     * 待注册机构列表
     */
    @ApiOperation("待注册机构列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "userId", required = true, value = "协销userId"),
            @ApiImplicitParam(name = "searchName", required = false, value = "搜索名称"),
            @ApiImplicitParam(name = "pageNum", required = true, value = "第几页"),
            @ApiImplicitParam(name = "pageSize", required = true, value = "一页多少条")
    })

    @GetMapping("/temporary/club")
    public ResponseJson<PageInfo<ClubTemporaryVo>> temporaryClub(Integer userId, String searchName,
                                                                 @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                                 @RequestParam(value = "pageSize", defaultValue = "10") int pageSize) {
        if (userId == null) {
            return ResponseJson.error("参数异常", null);
        }
        return sellerService.temporaryClub(userId, searchName, pageNum, pageSize);
    }

    /**
     * 修改待注册机构资料
     */
    @ApiOperation("修改待注册机构资料")
    @PostMapping("/modify/temporary/club")
    public ResponseJson<String> modifyTemporaryClub(ClubTemporaryDto temporaryDto) {
        if (temporaryDto.getId() == null || StringUtils.isBlank(temporaryDto.getBindMobile())) {
            return ResponseJson.error("参数异常", null);
        }
        return sellerService.modifyTemporaryClub(temporaryDto);
    }

    /**
     * 删除待注册机构资料
     */
    @ApiOperation("删除待注册机构资料")
    @PostMapping("/delete/temporary/club")
    public ResponseJson<String> deleteTemporaryClub(OnlineDto onlineDto) {
        if (onlineDto.getId() == null) {
            return ResponseJson.error("参数异常", null);
        }
        return sellerService.deleteTemporaryClub(onlineDto.getId());
    }


    /**
     * 协销机构列表
     * 原spi的 /seller/club/list
     *
     * @param spId 协销Id
     * @param status            机构状态
     * @param name              机构名字关键字（搜索用）
     */
    @ApiOperation("协销机构列表")
    @GetMapping("/club/list")
    public ResponseJson<PageInfo<ClubVo>> getClubList(Integer spId,
                                    Integer status,
                                    String name,
                                    Integer userIdentity,
                                    @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                    @RequestParam(value = "pageSize", defaultValue = "10") int pageSize) {
        if (null == spId || null == status) {
            return ResponseJson.error("spId 或 status 参数不全！", null);
        }
        return sellerService.getClubList(spId, status, name, userIdentity, pageNum, pageSize);
    }

    /**
     * 所有的机构列表
     * 原spi的 /seller/findAllClub
     * @param searchWord     关键字（搜索用）
     */
    @ApiOperation("所有的机构列表(搜索)")
    @GetMapping("/club/all")
    public ResponseJson<PageInfo<ClubVo>> getAllClubList(String searchWord,
                                                         @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                         @RequestParam(value = "pageSize", defaultValue = "10") int pageSize) {
        return sellerService.getAllClubList(searchWord, pageNum, pageSize);
    }

    /**
     * 协销个人中心
     *
     * @param userId 协销userId
     */
    @GetMapping("/home")
    public  ResponseJson<ServiceProviderPo> getSellerHome(Integer userId) {
        if (null == userId) {
            return ResponseJson.error("参数异常：用户Id不能为空！", null);
        }
        return sellerService.getSellerHome(userId);
    }

}
